TETRIS Stats
============

一个基于nonebot2的用于查询TETRIS相关游戏玩家数据的插件  
目前支持
* [TETR.IO](https://tetr.io/)
* [茶服](https://teatube.cn/tos/)
* [TOP](http://tetrisonline.pl/)

安装
----

* 使用 nb-cli
```
nb plugin install nonebot-plugin-tetris-stats
```

* 使用 pip
```
pip install nonebot-plugin-tetris-stats
```
* 对于 Windows
```
# CMD or PowerShell
playwright install firefox
```
* 对于 Linux
```
# 似乎 playwright官方 只支持 Ubuntu, 如果你是其他系统请自行尝试解决依赖问题
playwright install firefox
playwright install-deps firefox
```

使用
----

参考NoneBot2文档 [加载插件](https://v2.nonebot.dev/docs/tutorial/plugin/load-plugin/)

依赖
----

目前只支持 `OneBot V11` 协议

鸣谢
----

* [NoneBot2](https://v2.nonebot.dev/)
* [OneBot](https://onebot.dev/)
* [go-cqhttp](https://github.com/Mrs4s/go-cqhttp/)

开源
----

本项目使用[MIT](https://github.com/shoucandanghehe/nonebot-plugin-tetris-stats/blob/main/LICENSE)许可证开源
